# Django Manifest    [![Download Latest][image]][link]

[image]: https://img.shields.io/badge/Coverage-100%-success
[link]: https://github.com/ozgurgunes/Django-Manifest/releases/latest/download/django-manifest.zip


A kickstarter for Django Web Framework projects that supports both legacy frontend and javascript technolohies using REST API.

* Documentation: https://django-manifest.readthedocs.io
* Demo: https://django-manifest.github.io

## Features

* User registration & authentication.
* Password reset and email confirmation.
* Profile picture and settings.
* Future: Topic creation and branching.
* Future: User comments and rating.

## Installation

[Download][link] the latest release, unzip file.

#### Alternatively

Run in shell:

```
$ pip install django-manifest

```

See setup instructions.

## Documentation

* [Project Creation](https://django-manifest.readthedocs.io)
* [Frontend Integration](https://django-manifest.readthedocs.io)
